# Global Power Plant Database

The Global Power Plant Database is a comprehensive, open source database of power plants around the world [datasets.wri.org](https://datasets.wri.org/datasets/global-power-plant-database).

--object-name--

--urls--

| ![image](https://github.com/kamangir/assets/blob/main/blue-geo/global_power_plant_database-1.png?raw=true) | ![image](https://github.com/kamangir/assets/blob/main/blue-geo/global_power_plant_database-2.png?raw=true) |
|---|---|